[![version badge]](https://pypi.org/project/hive-service/)

[version badge]: https://img.shields.io/pypi/v/hive-service?color=limegreen

# hive-service

Common code for Hive services

## Installation

### With PIP

```sh
pip install hive-service
```
